#ifndef CONSTANTS_H
#define CONSTANTS_H
/* Copyright (C) 2015 by ETH Zürich
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU GPL (v>=2)
 * and comes with ABSOLUTELY NO WARRANTY!
 * See LICENSE.txt for details.
 */

/** @file constants.h
 * @brief Common definitions for this project.
 *
 * @details This file can be included to pull in common
 * definitions in the application. */

/**
 * @brief The version of the software package.
 *
 * Usually defined as Build parameter.
 */
#ifndef VERSION
#define VERSION "0.0.1"
#endif

/**
* @brief The user visible application name.
 *
 * Usually defined as Build parameter.
 **/
#ifndef APPNAME
#define APPNAME "unknown"
#endif

/**
* @brief Short command line description. */
#define DESCRIPTION "A tool to replay recorded user sessions."

/**
* @brief Short copyright notice to show users. */
#define COPYRIGHT "Copyright (C) 2015 ETH Zürich \n\n" \
                  "This file is Free Software under the GNU GPL (v>=2)\n" \
                  "and comes with ABSOLUTELY NO WARRANTY!\n"

/**
* @brief the config key for the last selected root folder. */
#define ROOT_FOLDER_KEY "RootFolder"

/**
* @brief the config key for the root folder info pattern. */
#define ROOT_FOLDER_PATTERN_KEY "RootFolderPattern"

/**
* @brief the default value for the root folder pattern */
#define DEFAULT_ROOT_PATTERN "Datum_LK-Nummer_Batch-Nr."

/**
* @brief the config key for the last selected subfolder. */
#define SUB_FOLDER_KEY "SubFolder"

/**
* @brief the config key for the sub folder info pattern. */
#define SUB_FOLDER_PATTERN_KEY "SubFolderPattern"

/**
* @brief the default value for the sub folder pattern */
//#define SUB_FOLDER_PATTERN "IP-Addr_Nethz-Login"
#define SUB_FOLDER_PATTERN "IP-Addr"

/**
* @brief how to format a timestamp */
#define LONG_DATE_FORMAT "dd.MM.yyyy, hh:mm:ss.zzz"

/**
* @brief the config key for the replay speed */
#define REPLAY_SPEED_KEY "Speed"

/**
* @brief the default value for the replay speed in seconds */
#define REPLAY_SPEED_DEFAULT 1.

/**
* @brief the value for a step in the speed slider */
#define REPLAY_SPEED_STEP_MS 500

/**
* @brief The seperator used in the patterns. */
#define PATTERN_SEPERATOR "_"

/**
* @brief The default sort column */
#define SORT_COLUMN_KEY "Sort"

/**
* @brief The default value for the sort column */
#define SORT_COLUMN_DEFAULT "Date"

/**
* @brief The default sort order (boolean) */
#define SORT_ORDER_KEY "SortAscending"

/**
* @brief The default sort order value. */
#define SORT_ORDER_VALUE true

/**
* @brief The column to use (counted from 0 and including index nr) for the filename */
#define FILENAME_COLUMN_IDX 1

/**
* @brief The column to use as the timestamp in the player window */
#define DATE_COLUMN_KEY "DisplayDate"

/**
* @brief The default value for the timestamp column */
#define DATE_COLUMN_DEFAULT "Date"

/**
* @brief The fallback value in case the DisplayDate column can't be found */
#define DATE_COLUMN_FALLBACK_IDX 2

/**
* @brief Setting to control wether or not the image can be detached. */
#define DETACHABLE_IMAGE_KEY "DetachableImage"

/**
* @brief Default value for the detachable image. */
#define DETACHABLE_IMAGE_DEFAULT false

/**
* @brief The configuration group for the tooltips. */
#define TOOLTIP_CONFIG_GROUP "Tooltips"

/**
* @brief The configuration group for hide settings */
#define HIDE_CONFIG_GROUP "Hidden"

#endif // CONSTANTS_H
